import unittest

from aurorastack.core import utils


class TestUtils(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        super(TestUtils, cls).setUpClass()

    @classmethod
    def tearDownClass(cls):
        super(TestUtils, cls).tearDownClass()

    def setUp(self):
        ...

    def tearDown(self):
        pass

    def test_parse_endpoint(self):
        url = 'file:///home/hojinshim/test.yaml'
        url_parsed = utils.parse_endpoint(url)
        print(url_parsed)
        self.assertEqual('file', url_parsed.get('scheme'))

        url = 'http://pyengine.net/hojinshim/test.yaml'
        url_parsed = utils.parse_endpoint(url)
        print(url_parsed)
        self.assertEqual('http', url_parsed.get('scheme'))

        url = 'https://pyengine.net/hojinshim/test.yaml'
        url_parsed = utils.parse_endpoint(url)
        print(url_parsed)
        self.assertEqual('https', url_parsed.get('scheme'))

        url = 'grpc://pyengine.net/hojinshim/test.yaml'
        url_parsed = utils.parse_endpoint(url)
        print(url_parsed)
        self.assertEqual('grpc', url_parsed.get('scheme'))



import unittest
from aurorastack.core.auth.jwt.jwt_util import JWTUtil


class TestJWTUtil(unittest.TestCase):

    @classmethod
    def setUpClass(cls) -> None:
        super(TestJWTUtil, cls).setUpClass()

    @classmethod
    def tearDownClass(cls) -> None:
        super(TestJWTUtil, cls).tearDownClass()

    def setUp(self) -> None:
        self.pub_jwk = None
        self.prv_jwk = None
        self.encoded = None
        self.payload = None

    def tearDown(self) -> None:
        self.pub_jwk = None
        self.prv_jwk = None
        self.payload = None
        self.encoded = None

    def test_generate_jwk(self):
        self.prv_jwk, self.pub_jwk = JWTUtil.generate_jwk()

        print(f'pub_jwk: {self.pub_jwk}')
        print(f'prv_jwk: {self.prv_jwk}')

        self.assertEqual(self.pub_jwk['n'], self.prv_jwk['n'])

    def test_encode_jwt(self):
        self.test_generate_jwk()

        self.payload = {
            'hello': 'world'
        }

        self.encoded = JWTUtil.encode(self.payload, self.prv_jwk)
        print(f'encoded: {self.encoded}')

        extracted = JWTUtil.unverified_decode(self.encoded)
        print(f'payload: {extracted}')
        self.assertDictEqual(self.payload, extracted)

    def test_decode_jwt(self):
        self.test_encode_jwt()
        decoded = JWTUtil.decode(self.encoded, self.pub_jwk)
        print(f'decoded: {decoded}')

        self.assertDictEqual(self.payload, decoded)



import unittest

from aurorastack.core.auth.jwt import JWTAuthenticator, JWTUtil
from aurorastack.core.error import ERROR_AUTHENTICATE_FAILURE


class TestJWTAuthenticator(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        super(TestJWTAuthenticator, cls).setUpClass()

    @classmethod
    def tearDownClass(cls):
        super(TestJWTAuthenticator, cls).tearDownClass()

    def setUp(self):
        self._generate_key()

    def _generate_key(self):
        self._prv_jwk, self._pub_jwk = JWTUtil.generate_jwk()
        self._jwt_auth = JWTAuthenticator(self._pub_jwk)

    def tearDown(self):
        pass

    def test_validate(self):
        payload = {
            'hello': 'world',
            'did': 'domain-0436002f575f'
        }
        encoded = JWTUtil.encode(payload, self._prv_jwk)

        decoded = self._jwt_auth.validate(encoded)
        self.assertDictEqual(payload, decoded)

    def test_invalid_token_content(self):
        encoded = '12345.12345.12345'
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(encoded)

        encoded = '1234512a34512345'
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(encoded)

        decimal = 1
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(decimal)

        dictionary = {}
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(dictionary)

        boolean = {}
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(boolean)

        float = 1.1
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(float)

        list = []
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(list)

        obj = object
        with self.assertRaises(ERROR_AUTHENTICATE_FAILURE):
            self._jwt_auth.validate(obj)



from aurorastack.core.logger.filters.error import ErrorFilter
from aurorastack.core.logger.filters.exclude import ExcludeFilter
from aurorastack.core.logger.filters.masking import MaskingFilter
from aurorastack.core.logger.filters.message import MessageJsonFilter
from aurorastack.core.logger.filters.parameter import ParameterFilter, ParameterLogFilter
from aurorastack.core.logger.filters.transaction import TransactionFilter
from aurorastack.core.logger.filters.traceback import TracebackFilter, TracebackLogFilter
